#ifndef __GPIO_K20_H
#define __GPIO_K20_H

#include <stdint.h>
#include <stdbool.h>

#include "MK20D5.h"

#if defined (__CC_ARM)
#define __FORCE_INLINE  static __forceinline
#else
#define __FORCE_INLINE  __STATIC_INLINE
#endif

/// GPIO Alternate Function identifier
typedef enum _GPIO_AF_ID {
  GPIO_AF_PIN_DISABLED          = 0,
  GPIO_AF_GPIO                  = 1,
  GPIO_AF_ALT1                  = 1,
  GPIO_AF_ALT2                  = 2,
  GPIO_AF_ALT3                  = 3,
  GPIO_AF_ALT4                  = 4,
  GPIO_AF_ALT5                  = 5,
  GPIO_AF_ALT6                  = 6,
  GPIO_AF_ALT7                  = 7
} GPIO_AF_ID;

/// GPIO Pin identifier
typedef struct _PORT_PIN_ID {
  PORT_Type *port;                   // ptr to port
  uint8_t    num;                    // pin number
  GPIO_AF_ID af;                     // pin alternate function
} PORT_PIN_ID;



void GPIO_PortClock (PORT_Type *PORTx, bool clock);

/**
  \fn          bool GPIO_PinAF (GPIO_TypeDef *GPIOx,
                                uint32_t      num,
                                uint32_t      af)
  \brief       Setup port pin alternate function
  \param[in]   GPIOx  Pointer to GPIO peripheral
  \param[in]   num    Port pin number
  \param[in]   af     \ref GPIO_AF_ID
  \return      true  - success
               false - error
*/
bool GPIO_PinAF (PORT_Type *PORTx,
                 uint32_t      num,
                 GPIO_AF_ID    af);

/**
  \fn          void GPIO_PinWrite (GPIO_TypeDef *GPIOx, uint32_t num, uint32_t val)
  \brief       Write port pin
  \param[in]   GPIOx  Pointer to GPIO peripheral
  \param[in]   num    Port pin number
  \param[in]   val    Port pin value (0 or 1)
*/
void GPIO_PinWrite (PORT_Type *PORTx, uint32_t num, uint32_t val);

/**
  \fn          uint32_t GPIO_PinRead (GPIO_TypeDef *GPIOx, uint32_t num)
  \brief       Read port pin
  \param[in]   GPIOx  Pointer to GPIO peripheral
  \param[in]   num    Port pin number
  \return      pin value (0 or 1)
*/
uint32_t GPIO_PinRead (PORT_Type *PORTx, uint32_t num);

/**
  \fn          void GPIO_PortWrite (GPIO_TypeDef *GPIOx, uint16_t mask, uint16_t val)
  \brief       Write port pins
  \param[in]   GPIOx  Pointer to GPIO peripheral
  \param[in]   mask   Selected pins
  \param[in]   val    Pin values
*/
void GPIO_PortWrite (PORT_Type *PORTx, uint16_t mask, uint16_t val);

/**
  \fn          uint16_t GPIO_PortRead (GPIO_TypeDef *GPIOx)
  \brief       Read port pins
  \param[in]   GPIOx  Pointer to GPIO peripheral
  \return      port pin inputs
*/
uint16_t GPIO_PortRead (PORT_Type *PORTx);



#endif /* __GPIO_K20_H */
